#!/bin/bash


# Define variables
PLATFORMTOOLS_DIRECTORY="platform-tools/linux"



# Check if platform-tools directory exists
if [ ! -d "$PLATFORMTOOLS_DIRECTORY" ]; then
    echo "Missing directory $PLATFORMTOOLS_DIRECTORY!"
    read -p "Press enter to continue..."
    exit
fi

# Update the PATH
PATH="$PATH:$PLATFORMTOOLS_DIRECTORY"



retry() {
    clear

    kill_adb
    start_adb

    echo "Waiting for device"

    if adb devices | grep -i "device$" > /dev/null; then
        success
        return
    fi

    echo "Please wait...."
    sleep 2

    clear
    retry
}



success() {
    echo "Installing Apps..."
    for i in "$(dirname "$0")/apks/"*.apk; do
        adb install -t -r -d "$i"
    done

    read -p "Press enter to continue..."
}



start_adb() {
    echo "Starting ADB server..."
    adb start-server
}



kill_adb() {
    if pgrep adb > /dev/null; then
        echo "Killing ADB server..."
        adb kill-server
        sleep 1
    fi
}



# Start the retry process
retry
